| bind_varimax_z | R Documentation |
Add Z factor loadings to node table of tidygraph
bind_varimax_z(graph, fa, ...)
bind_varimax_y(graph, fa, ...)
bind_svd_u(graph, fa, ...)
bind_svd_v(graph, fa, ...)
graph |
A tidygraph::tbl_graph object. |
fa |
Optionally, a vsp object to extract varimax loadings from. If you do not passed a vsp object, one will be created. |
... |
Arguments passed on to
|
The same graph object with columns factor1, ..., factor{rank}
in the table of node information.
bind_varimax_y(): Add Y factor loadings to node table of tidygraph
bind_svd_u(): Add left singular vectors to node table of tidygraph
bind_svd_v(): Add right singular vectors to node table of tidygraph
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.