plot_mixing_matrix: Plot the mixing matrix B

plot_mixing_matrixR Documentation

Plot the mixing matrix B

Description

Plot the mixing matrix B

Usage

plot_mixing_matrix(fa)

Arguments

fa

A vsp_fa() object.

Value

A tibble::tibble() with one row for each node, and one column containing each of the requested factor or singular vector, plus an additional id column.


vsp documentation built on April 17, 2026, 1:07 a.m.