| set_z_factor_names | R Documentation |
Give the dimensions of Z factors informative names
set_z_factor_names(fa, names)
set_y_factor_names(fa, names)
fa |
A |
names |
Describe new names for Z/Y factors. |
A new vsp_fa() object, but the columns names of Z and the
row names of B have been set to names (for set_z_factor_names),
and the column names of B and the column names of Y have been
set to names (for set_y_factor_names).
set_y_factor_names(): Give the dimensions of Y factors informative names
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.